<table border="1">
    <tr>
	<th>svctag</th>
        {% for field  in fields %}
            {% if field != "svctag" %}
                <th>{{ field }}</th>
            {% endif %}
        {% endfor %}
    </tr>
    {% for mach in mach_info.all() %}
        <tr>
            <td>{{ mach.svctag }}</td>
            {% for value  in vars(mach).values() %}
                {% if mach.svctag != value %}
                    <td>{{ value }}</td>
                {% endif %}
            {% endfor %}
        </tr>
    {% endfor %}
</table>
                
